@@ -17,6 +17,13 @@
 
 _INNER_BOT_QUERY = """
     _id
+    config {
+        _id
+        profile {
+            _id
+            name
+        }
+    }
     name
     device {
       _id
@@ -27,12 +34,12 @@ _INNER_BOT_QUERY = """
     }
     deployment {
       _id
-      host
-      region
-      status
       subscription_id
       type
-      uuid
+    }
+    stats {
+        _id
+        profitability
     }
     user_id
 """
@@ -76,3 +83,16 @@ mutation CreateBotDevice($bot_id: ObjectId) {
   }
 }
     """, {"bot_id": bot_id}
+
+
+def update_bot_config_and_stats_query(bot_id, profile_name, profitability) -> (str, dict):
+    return """
+mutation updateOneBot($bot_id: ObjectId, $profile_name: String, $profitability: Float) {
+  updateOneBot(
+    query: {_id: $bot_id}
+    set: {config: {profile: {name: $profile_name}}, stats: {profitability: $profitability}}
+  ) {
+    """ + _INNER_BOT_QUERY + """
+  }
+}
+    """, {"bot_id": bot_id, "profile_name": profile_name, "profitability": profitability}
